Puppeter - an automatic puppet installer
========================================

.. image:: https://travis-ci.org/coi-gov-pl/puppeter.svg?branch=develop
    :target: https://travis-ci.org/coi-gov-pl/puppeter
.. image:: https://coveralls.io/repos/github/coi-gov-pl/puppeter/badge.svg?branch=feature%2Finstall-puppet-agent
    :target: https://coveralls.io/github/coi-gov-pl/puppeter?branch=feature%2Finstall-puppet-agent


A commandline tool to ease the installation of typical puppetserver - agent installation. It uses a interactive mode and batch mode as well. Batch mode utilizes a answer files for full automatic operation.

**TODO: Write more later**
